"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.removeMarkTags = exports.removeCodeLanguageTags = exports.regReplaceAll = exports.qualifyMarkdownText = exports.prepareCodeText = exports.getCodeLanguageFromTaggedText = exports.addMarkTags = exports.addCodeLanguageTags = void 0;
var _utils = require("../utils");
var regReplaceAll = (content, pattern, replacementFunc) => {
  var target = new RegExp(pattern, 'gi');
  return content.replace(target, replacementFunc);
};
exports.regReplaceAll = regReplaceAll;
var addMarkTags = (content, searchPattern) => {
  var markedContent;
  try {
    var replacement = match => "<mark>".concat(match, "</mark>");
    markedContent = regReplaceAll(content, searchPattern, replacement);
  } catch (e) {
    markedContent = content;
  }
  return markedContent;
};
exports.addMarkTags = addMarkTags;
var removeMarkTags = markedText => {
  return markedText.replace(/<\/?mark>/g, '');
};
exports.removeMarkTags = removeMarkTags;
var addCodeLanguageTags = content => {
  var languageTaggedContent;
  try {
    var searchPattern = /```([A-Za-z]+)$/gm;
    var match = searchPattern.exec(content);
    var language = match && match[1];
    var replacement = () => "```\n<".concat(language, "/>");
    languageTaggedContent = content.replace(searchPattern, replacement);
  } catch (e) {
    languageTaggedContent = content;
  }
  return languageTaggedContent;
};
exports.addCodeLanguageTags = addCodeLanguageTags;
var removeCodeLanguageTags = content => {
  var untaggedContent;
  try {
    var replacement = () => '';
    var searchPattern = /<(.*)\/>$/gm;
    var match = searchPattern.exec(content);
    var language = match && match[1];
    if (language && (0, _utils.instanceOfPrismLanguage)(language)) {
      untaggedContent = regReplaceAll(content, '<' + language + '/>\n', replacement);
    } else {
      untaggedContent = content;
    }
  } catch (e) {
    untaggedContent = content;
  }
  return untaggedContent;
};
exports.removeCodeLanguageTags = removeCodeLanguageTags;
var getCodeLanguageFromTaggedText = content => {
  var searchPattern = /<(.*)\/>$/gm;
  var match = searchPattern.exec(content);
  return match ? match[1] : 'markup';
};
exports.getCodeLanguageFromTaggedText = getCodeLanguageFromTaggedText;
var prepareCodeText = content => {
  var text = content;
  var language = getCodeLanguageFromTaggedText(text);
  text = removeCodeLanguageTags(text);
  text = removeMarkTags(text);
  text = text.trim();
  return {
    text,
    language
  };
};
exports.prepareCodeText = prepareCodeText;
var qualifyMarkdownText = (content, pattern) => {
  var qualifiedContent;
  if (pattern !== '') {
    qualifiedContent = addMarkTags(content, pattern);
  }
  qualifiedContent = addCodeLanguageTags(qualifiedContent || content);
  return qualifiedContent;
};
exports.qualifyMarkdownText = qualifyMarkdownText;
//# sourceMappingURL=utils.js.map